'use strict';

var cypressUtils_utils_common = require('./common.js');
var cypressUtils_constants_routes = require('../constants/routes.js');
var cypressUtils_constants_selectors_common = require('../constants/selectors/common.js');
var cypressUtils_constants_selectors_signUp = require('../constants/selectors/signUp.js');
var cypressUtils_constants_texts_signUp = require('../constants/texts/signUp.js');
require('../../defineProperty-BB_r6qQ2.js');
require('../../toPropertyKey-CRgrohXG.js');
require('../../typeof-D4ZZ_FlZ.js');
require('../constants/index.js');

var extractSubdomainFromError = function extractSubdomainFromError(inputString) {
  var regex = /cpt[a-zA-Z0-9-]+/g;
  var matches = inputString.match(regex);
  return matches[1];
};
var _updateSubdomainIfExists = function updateSubdomainIfExists(appName) {
  cy.ifExist(cypressUtils_constants_selectors_signUp.signUpSelectors.subdomainError, function () {
    cy.get(cypressUtils_constants_selectors_signUp.signUpSelectors.subdomainError).invoke("text").then(function (text) {
      cy.intercept({
        url: cypressUtils_constants_routes.requestApis.subdomainAvailability,
        times: 1
      }).as("subdomainRequest");
      var newOrganizationName = extractSubdomainFromError(text);
      cy.clearAndType(cypressUtils_constants_selectors_signUp.signUpSelectors.subdomainNameTextField, newOrganizationName);
      cy.wait("@subdomainRequest");
      cy.ifNotExist(cypressUtils_constants_selectors_signUp.signUpSelectors.subdomainError, function () {
        cy.task("updateGlobalState", {
          key: "subdomainName",
          value: newOrganizationName
        });
        cy.task("updateGlobalState", {
          key: "businessName",
          value: newOrganizationName
        });
        var newBaseUrl = "https://".concat(newOrganizationName, ".").concat(appName, ".").concat(cypressUtils_utils_common.env.tld);
        Cypress.config("baseUrl", newBaseUrl);
        cy.clearAndType(cypressUtils_constants_selectors_signUp.signUpSelectors.organizationNameTextField, newOrganizationName);
      });
    });
    cy.ifExist(cypressUtils_constants_selectors_signUp.signUpSelectors.subdomainError, function () {
      return _updateSubdomainIfExists(appName);
    });
  });
};
var createOrganization = function createOrganization(_ref) {
  var email = _ref.email,
    businessName = _ref.businessName,
    subdomainName = _ref.subdomainName,
    firstName = _ref.firstName,
    lastName = _ref.lastName,
    appName = _ref.appName;
  var isMailosaurEmail = email.includes("mailosaur");
  var defaultOtp = "123456";
  var appNameInLowerCase = appName.toLowerCase();
  var isNeetoAuth = appNameInLowerCase === "neetoauth";
  var authUrl = "https://app.neetoauth.".concat(cypressUtils_utils_common.env.tld, "/signups/new");
  isNeetoAuth ? cy.visit(authUrl) : cy.visit("".concat(authUrl, "?redirect_uri=").concat(appNameInLowerCase, ".").concat(cypressUtils_utils_common.env.tld));
  cy.clearAndType(cypressUtils_constants_selectors_signUp.signUpSelectors.emailTextField, email);
  cy.intercept({
    url: cypressUtils_constants_routes.requestApis.signUp,
    times: 2
  }).as("signupRequest");
  cy.get(cypressUtils_constants_selectors_signUp.signUpSelectors.submitButton).click();
  cy.wait("@signupRequest");
  if (isMailosaurEmail) {
    cy.getEmailContent({
      sentTo: email,
      subject: cypressUtils_constants_texts_signUp.signUpTexts.loginCode
    }).then(function (emailBody) {
      var otp = emailBody.html.codes[0].value;
      cy.get(cypressUtils_constants_selectors_signUp.signUpSelectors.otpTextBox).type(otp);
    });
  } else cy.get(cypressUtils_constants_selectors_signUp.signUpSelectors.otpTextBox).type(defaultOtp);
  cy.wait("@signupRequest");
  cy.intercept({
    url: cypressUtils_constants_routes.requestApis.subdomainAvailability,
    times: 1
  }).as("subdomainRequest");
  cy.clearAndType(cypressUtils_constants_selectors_signUp.signUpSelectors.organizationNameTextField, businessName);
  cy.clearAndType(cypressUtils_constants_selectors_signUp.signUpSelectors.subdomainNameTextField, subdomainName);
  cy.wait("@subdomainRequest");
  _updateSubdomainIfExists(appNameInLowerCase);
  cy.intercept({
    url: cypressUtils_constants_routes.requestApis.signUp,
    times: 1
  }).as("signupRequest");
  cy.intercept({
    url: cypressUtils_constants_routes.requestApis.countries,
    times: 1
  }).as("fetchCountries");
  cy.get(cypressUtils_constants_selectors_signUp.signUpSelectors.organizationSubmitButton).click();
  cy.wait("@signupRequest");
  cy.url({
    timeout: 15000
  }).should("include", cypressUtils_constants_texts_signUp.signUpTexts.profile);
  cy.wait("@fetchCountries");
  cy.clearAndType(cypressUtils_constants_selectors_signUp.signUpSelectors.firstNameTextField, firstName);
  cy.clearAndType(cypressUtils_constants_selectors_signUp.signUpSelectors.lastNameTextField, lastName);
  cy.get(cypressUtils_constants_selectors_common.commonSelectors.checkbox).click();
  cy.intercept({
    url: cypressUtils_constants_routes.requestApis.signUp,
    times: 1
  }).as("setupProfile");
  cy.get(cypressUtils_constants_selectors_signUp.signUpSelectors.profileSubmitButton).click();
  cy.wait("@setupProfile");
};

exports.createOrganization = createOrganization;
//# sourceMappingURL=organization.js.map
